@@ -17,7 +17,8 @@
  * This is only used when compiled with pthreads.
  */
 #ifdef PDL_PTHREAD
-static pthread_t pdl_main_pthreadID = 0;
+static pthread_t pdl_main_pthreadID;
+static int done_pdl_main_pthreadID_init = 0;
 
 /* deferred error messages are stored here. We can only barf/warn from the main
  *  thread, so worker threads complain here and the complaints are printed out
@@ -265,16 +266,17 @@ int pdl_pthreads_enabled(void) {return 1;}
 
 static void *pthread_perform(void *vp) {
 	struct ptarg *p = (ptarg *)vp;
-	if(TVERB) printf("STARTING THREAD %d (%d)\n",p->no, pthread_self());
+	/* if(TVERB) printf("STARTING THREAD %d (%d)\n",p->no, pthread_self()); */
+	if(TVERB) printf("STARTING THREAD number %d\n",p->no);
 	pthread_setspecific(p->mag->key,(void *)&(p->no));
 	(p->func)(p->t);
-	if(TVERB) printf("ENDING THREAD %d (%d)\n",p->no, pthread_self());
+	/* if(TVERB) printf("ENDING THREAD %d (%d)\n",p->no, pthread_self());   */
+	if(TVERB) printf("ENDING THREAD number %d\n",p->no);
 	return NULL;
 }
 
 int pdl_magic_thread_nthreads(pdl *it,int *nthdim) {
-	pdl_magic_pthread *ptr = (pdl_magic_pthread *)pdl__find_magic(it,
-					PDL_MAGIC_THREADING);
+	pdl_magic_pthread *ptr = (pdl_magic_pthread *)pdl__find_magic(it, PDL_MAGIC_THREADING);
 	if(!ptr) return 0;
 	*nthdim = ptr->nthdim;
 	return ptr->nthreads;
@@ -283,8 +285,7 @@ int pdl_magic_thread_nthreads(pdl *it,int *nthdim) {
 int pdl_magic_get_thread(pdl *it) { /* XXX -> only one thread can handle pdl at once */
 	pdl_magic_pthread *ptr;
 	int *p;
-	ptr = (pdl_magic_pthread *)pdl__find_magic(it,
-					PDL_MAGIC_THREADING);
+	ptr = (pdl_magic_pthread *)pdl__find_magic(it, PDL_MAGIC_THREADING);
 	if(!ptr) {die("Invalid pdl_magic_get_thread!");}
 	p = (int*)pthread_getspecific(ptr->key);
 	if(!p) {
@@ -301,60 +302,60 @@ void pdl_magic_thread_cast(pdl *it,void (*func)(pdl_trans *),pdl_trans *t, pdl_t
 	SV * barf_msg;	  /* Deferred barf message. Using a perl SV here so it's memory can be freeed by perl
 						 after it is sent to croak */
 	SV * warn_msg;	  /* Similar deferred warn message. */
-					  
-	ptr = (pdl_magic_pthread *)pdl__find_magic(it,
-					PDL_MAGIC_THREADING);
+
+	ptr = (pdl_magic_pthread *)pdl__find_magic(it, PDL_MAGIC_THREADING);
 	if(!ptr) {
 		/* Magic doesn't exist, create it
 			Probably was deleted before the transformation performed, due to
 			pdl lazy evaluation.
 		*/
-		
+
 		pdl_add_threading_magic(it, thread->mag_nth, thread->mag_nthr);
 		clearMagic = 1; /* Set flag to delete magic later */
-		
+
 		/* Try to get magic again */
-		ptr = (pdl_magic_pthread *)pdl__find_magic(it,
-						PDL_MAGIC_THREADING);
-						
+		ptr = (pdl_magic_pthread *)pdl__find_magic(it, PDL_MAGIC_THREADING);
+
 		if(!ptr) {die("Invalid pdl_magic_thread_cast!");}
-				
+
 	}
-	
+
 	tp = malloc(sizeof(pthread_t) * thread->mag_nthr);
 	tparg = malloc(sizeof(*tparg) * thread->mag_nthr);
 	pthread_key_create(&(ptr->key),NULL);
-	if(TVERB) printf("CREATING THREADS, ME: %d, key: %d\n",pthread_self(),
-		ptr->key);
-		
-	/* Get the pthread ID of this main thread we are in. 
+	/* if(TVERB) printf("CREATING THREADS, ME: %d, key: %d\n",pthread_self(), ptr->key); */
+	if(TVERB) printf("CREATING THREADS, ME: TBD, key: %d\n", ptr->key);
+
+	/* Get the pthread ID of this main thread we are in.
 	 *	Any barf, warn, etc calls in the spawned pthreads can use this
 	 *	to tell if its a spawned pthread
 	 */
-	pdl_main_pthreadID = pthread_self();
-	
-	
-	for(i=0; i<thread->mag_nthr; i++) {
-		tparg[i].mag = ptr;
-		tparg[i].func = func;
-		tparg[i].t = t;
-		tparg[i].no = i;
-		pthread_create(tp+i, NULL, pthread_perform, tparg+i);
-	}
-	if(TVERB) printf("JOINING THREADS, ME: %d, key: %d\n",pthread_self(),
-		ptr->key);
+	pdl_main_pthreadID = pthread_self();   /* should do inside pthread_once() */
+    done_pdl_main_pthreadID_init = 1;
+
+    for(i=0; i<thread->mag_nthr; i++) {
+        tparg[i].mag = ptr;
+        tparg[i].func = func;
+        tparg[i].t = t;
+        tparg[i].no = i;
+        if (pthread_create(tp+i, NULL, pthread_perform, tparg+i)) {
+            die("Unable to create pthreads!");
+        }
+    }
+	/* if(TVERB) printf("JOINING THREADS, ME: %d, key: %d\n",pthread_self(), ptr->key); */
+	if(TVERB) printf("JOINING THREADS, ME: TBD, key: %d\n", ptr->key);
 	for(i=0; i<thread->mag_nthr; i++) {
 		pthread_join(tp[i], NULL);
 	}
-	if(TVERB) printf("FINISHED THREADS, ME: %d, key: %d\n",pthread_self(),
-		ptr->key);
+	/* if(TVERB) printf("FINISHED THREADS, ME: %d, key: %d\n",pthread_self(), ptr->key); */
+	if(TVERB) printf("FINISHED THREADS, ME: TBD, key: %d\n", ptr->key);
 	pthread_key_delete((ptr->key));
-	
+
 	/* Remove pthread magic if we created in this function */
 	if( clearMagic ){
 		pdl_add_threading_magic(it, -1, -1);
 	}
-	
+
 	/* Clean up memory allocated */
 	free(tp);
 	free(tparg);
@@ -383,32 +384,32 @@ void pdl_magic_thread_cast(pdl *it,void (*func)(pdl_trans *),pdl_trans *t, pdl_t
 /* Function to remove threading magic (added by pdl_add_threading_magic) */
 void pdl_rm_threading_magic(pdl *it)
 {
-	pdl_magic_pthread *ptr = (pdl_magic_pthread *)pdl__find_magic(it,
-					PDL_MAGIC_THREADING);
-					
+	pdl_magic_pthread *ptr = (pdl_magic_pthread *)pdl__find_magic(it, PDL_MAGIC_THREADING);
+
 	/* Don't do anything if threading magic not found */
 	if( !ptr) return;
-	
+
 	/* Remove magic */
 	pdl__magic_rm(it, (pdl_magic *) ptr);
-	
+
 	/* Free magic */
 	free( ptr );
 }
-	
+
 /* Function to add threading magic (i.e. identify which PDL dimension should
    be pthreaded and how many pthreads to create
-   Note: If nthdim and nthreads = -1 then any pthreading magic is removed */	
+   Note: If nthdim and nthreads = -1 then any pthreading magic is removed */
 void pdl_add_threading_magic(pdl *it,int nthdim,int nthreads)
 {
+      pdl_magic_pthread *ptr;
 
 	/* Remove threading magic if called with parms -1, -1 */
 	if( (nthdim == -1) && ( nthreads == -1 ) ){
 		 pdl_rm_threading_magic(it);
 		 return;
 	}
-		
-	pdl_magic_pthread *ptr = malloc(sizeof(pdl_magic_pthread));
+
+	ptr = malloc(sizeof(pdl_magic_pthread));
 	ptr->what = PDL_MAGIC_THREADING;
 	ptr->vtable = NULL;
 	ptr->next = NULL;
@@ -425,12 +426,13 @@ void pdl_add_threading_magic(pdl *it,int nthdim,int nthreads)
 // reporting later
 int pdl_pthread_barf_or_warn(const char* pat, int iswarn, va_list *args)
 {
-	/* Don't do anything if we are in the main pthread */
-	if( !pdl_main_pthreadID || pthread_equal( pdl_main_pthreadID, pthread_self() ) )
-		return 0;
-
 	char** msgs;
 	int*   len;
+
+	/* Don't do anything if we are in the main pthread */
+	if( !done_pdl_main_pthreadID_init || pthread_equal( pdl_main_pthreadID, pthread_self() ) )
+		return 0;
+
 	if(iswarn)
 	{
 		msgs = &pdl_pthread_warn_msgs;
@@ -443,26 +445,28 @@ int pdl_pthread_barf_or_warn(const char* pat, int iswarn, va_list *args)
 	}
 
 	// add the new complaint to the list
-	static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
-	pthread_mutex_lock( &mutex );	
 	{
-		// In the chunk I'm adding I need to store the actual data and a trailing
-		// newline.
-		int extralen = vsnprintf(NULL, 0, pat, *args) + 1;
+		static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
+		pthread_mutex_lock( &mutex );
+		{
+			// In the chunk I'm adding I need to store the actual data and a trailing
+			// newline.
+			int extralen = vsnprintf(NULL, 0, pat, *args) + 1;
 
-		// 1 more for the trailing '\0'
-		*msgs = realloc(*msgs, *len + extralen + 1);
-		vsnprintf( *msgs + *len, extralen + 1, pat, *args);
+			// 1 more for the trailing '\0'
+			*msgs = realloc(*msgs, *len + extralen + 1);
+			vsnprintf( *msgs + *len, extralen + 1, pat, *args);
 
-		// update the length-so-far. This does NOT include the trailing '\0'
-		*len += extralen;
+			// update the length-so-far. This does NOT include the trailing '\0'
+			*len += extralen;
 
-		// add the newline to the end
-		(*msgs)[*len-1] = '\n';
-		(*msgs)[*len  ] = '\0';
+			// add the newline to the end
+			(*msgs)[*len-1] = '\n';
+			(*msgs)[*len  ] = '\0';
+		}
+		pthread_mutex_unlock( &mutex );
 	}
-	pthread_mutex_unlock( &mutex );
-	
+
 	if(iswarn)
 	{
 		/* Return 1, indicating we have handled the warn messages */
@@ -472,8 +476,8 @@ int pdl_pthread_barf_or_warn(const char* pat, int iswarn, va_list *args)
 	/* Exit the current pthread. Since this was a barf call, and we should be halting execution */
 	pthread_exit(NULL);
 	return 0;
-}	
-	
+}
+
 
 #else
 /* Dummy versions */
